import PDFKit

final class CustomPDFView: PDFView {

  override var canZoomIn: Bool {
    return false
  }
  
  func setDocument(_ document: PDFDocument?) {
    displayMode = .singlePage
    autoScales = true
    displayDirection = .horizontal
    autoresizingMask = [.flexibleWidth, .flexibleHeight]
    self.document = document
    usePageViewController(true, withViewOptions: nil)
    hideScrollViewIndicator()
  }
}

extension PDFView {
  func hideScrollViewIndicator() {
    let scrollView = allSubviews.compactMap { $0 as? UIScrollView }.first
    scrollView?.showsHorizontalScrollIndicator = false
    scrollView?.showsVerticalScrollIndicator = false
  }
  
  func getCurrentPageIndex() -> Int {
    guard let currentPage = visiblePages.first, let document = document else {
      return 1
    }
    
    let index = document.index(for: currentPage)
    return index
  }
}
