//
//  UIButton+Extensions.swift
//  MiniScanner
//
//  Created by George Makhoul on 09/06/2024.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import UIKit

extension UIButton {
    
    // MARK: - Set Title
    func set(title: String?) {
        setTitle(title, for: .normal)
        
        contentVerticalAlignment = .center
        contentHorizontalAlignment = .center
    }
    
    func set(localized: String?) {
        guard let title = localized else { return }
        
        setTitle(title.localized, for: .normal)
        
        contentVerticalAlignment = .center
        contentHorizontalAlignment = .center
    }
    
    func set(color: UIColor?) {
        setTitleColor(color, for: .normal)
    }
    
    func set(font: UIFont?) {
        titleLabel?.font = font
    }
    
    func set(title: String?, color: UIColor?, font: UIFont?) {
        set(title: title)
        set(color: color)
        set(font: font)
    }
    
    func set(localized: String?, color: UIColor?, font: UIFont?) {
        set(localized: localized)
        set(color: color)
        set(font: font)
    }
    
    // MARK: - Set Icon
    func set(icon: UIImage = UIImage(named: "") ?? UIImage()) {
            setImage(icon.withRenderingMode(.alwaysOriginal), for: .normal)
        
        contentMode = .center
        clipsToBounds = false
        
        contentVerticalAlignment = .center
        contentHorizontalAlignment = .center
    }
    
    func set(colorBackground:UIColor){
        backgroundColor = colorBackground
    }
}

