//
//  UIColor+Extensions.swift
//  MiniScanner
//
//  Created by George Makhoul on 08/06/2024.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import Foundation
import UIKit

extension UIColor {
    static let mainBlue = hex("#007EFF")
    static let buttonsBlue = hex("#1F86FF")
    static let mainText = hex("#505050")
    static let titlesText = hex("#888888")
    static let cellBackground = hex("#F4F4F4")
    static let lightButton = hex("#E9EDF2")
    static let separator = hex("#646464")
}

extension UIColor {
    /**
     Creates an UIColor from HEX String in "#363636" format
     - parameter hexString: HEX String in "#363636" format
     - returns: UIColor from HexString
     */
    convenience init(hexString: String, alpha: CGFloat = 1.0) {
        
        var hexString: String = hexString.trimmingCharacters(in: .whitespacesAndNewlines)
        
        if hexString.hasPrefix("#") {
            hexString.remove(at: hexString.startIndex)
        }
        
        var color: UInt64 = 0
        Scanner(string: hexString).scanHexInt64(&color)
        
        let red   = CGFloat((color & 0xFF0000) >> 16) / 255.0
        let green = CGFloat((color & 0x00FF00) >> 8) / 255.0
        let blue  = CGFloat(color & 0x0000FF) / 255.0
        
        self.init(red: red, green: green, blue: blue, alpha: alpha)
    }
    
    /**
     Creates an UIColor Object based on provided RGB value in integer
     - parameter red:   Red Value in integer (0-255)
     - parameter green: Green Value in integer (0-255)
     - parameter blue:  Blue Value in integer (0-255)
     - returns: UIColor with specified RGB values
     */
    convenience init(red: Int, green: Int, blue: Int) {
        self.init(red: CGFloat(red) / 255.0, green: CGFloat(green) / 255.0, blue: CGFloat(blue) / 255.0, alpha: 1.0)
    }
    
    convenience init(red: Int, green: Int, blue: Int, alpha: CGFloat) {
        self.init(red: CGFloat(red) / 255.0, green: CGFloat(green) / 255.0, blue: CGFloat(blue) / 255.0, alpha: alpha)
    }
    
    class func hex(_ hexCode: String) -> UIColor {
        return UIColor(hexString: hexCode)
    }
    
    class func hex(code: String, alpha: CGFloat) -> UIColor {
        return UIColor(hexString: code, alpha: alpha)
    }
    
    class func rgb(_ red: Int, _ green: Int, _ blue: Int) -> UIColor {
        return UIColor(red: red, green: green, blue: blue)
    }
    
    class func rgba(_ red: Int, _ green: Int, _ blue: Int, alpha: CGFloat) -> UIColor {
        return UIColor(red: red, green: green, blue: blue, alpha: alpha)
    }
}
