//
//  UIFont+Extensions.swift
//  MiniScanner
//
//  Created by George Makhoul on 08/06/2024.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import UIKit

extension UIFont {
    
    // MARK: - Font Name
    enum AppFont {
        case extrabold
        case bold
        case black
        case medium
        case regular
        case light
        case extralight
        
        enum English: String {
            case bold = "Poppins-Bold"
            case medium = "Poppins-Medium"
            case regular = "Poppins-Regular"
        }
        
        enum Arabic: String {
            case extrabold = "Tajawal-ExtraBold"
            case bold = "Tajawal-Bold"
            case black = "Tajawal-Black"
            case medium = "Tajawal-Medium"
            case regular = "Tajawal-Regular"
            case light = "Tajawal-Light"
            case extralight = "Tajawal-ExtraLight"
        }
        
        func font() -> String {
            switch self {
            case .bold:
                return lang == .en ? English.bold.rawValue : Arabic.bold.rawValue
            case .regular:
                return lang == .en ? English.regular.rawValue : Arabic.regular.rawValue
            case .medium:
                return lang == .en ? English.medium.rawValue : Arabic.medium.rawValue
            case .light:
                return lang == .en ? English.regular.rawValue : Arabic.light.rawValue
            case .extrabold:
                return lang == .en ? English.bold.rawValue : Arabic.extrabold.rawValue
            case .black:
                return lang == .en ? English.bold.rawValue : Arabic.black.rawValue
            case .extralight:
                return lang == .en ? English.regular.rawValue : Arabic.extralight.rawValue

            }
        }
    }
}

extension UIFont {
    // MARK: - Get Font
    static func getFont(_ name: UIFont.AppFont, size: CGFloat) -> UIFont {
        return getFont(name: name.font(), size: size)
    }
    
    static func getFont(name: String, size: CGFloat) -> UIFont {
        if let font = UIFont(name: name, size: size) {
            return font
        } else {
            return UIFont.systemFont(ofSize: size)
        }
    }
    
    // MARK: - Font Styles
    class func light(_ size: CGFloat) -> UIFont {
        getFont(.light, size: size)
    }
    
    class func regular(_ size: CGFloat) -> UIFont {
        getFont(.regular, size: size)
    }
    
    class func medium(_ size: CGFloat) -> UIFont {
        getFont(.medium, size: size)
    }
        
    class func bold(_ size: CGFloat) -> UIFont {
        getFont(.bold, size: size)
    }
    
    class func extraBold(_ size: CGFloat) -> UIFont {
        getFont(.extrabold, size: size)
    }
    
    class func extraLight(_ size: CGFloat) -> UIFont {
        getFont(.extralight, size: size)
    }
    
    class func black(_ size: CGFloat) -> UIFont {
        getFont(.black, size: size)
    }
}

