//
//  ThemeManager.swift
//  DocScan
//
//  Created by Mister Grizzly.
//

import UIKit

final class ThemeManager {
  
  static let shared = ThemeManager()
  
  /// Setups the appearance proxy for the UINavigationBar, UIToolbar and UIButton.
  func setupTheme() {
    let navigationBarAppearace = UINavigationBar.appearance()
    
    navigationBarAppearace.tintColor = .tintColor
    navigationBarAppearace.barTintColor = .barTintColor
    
    let toolBarAppearace = UIToolbar.appearance()
    
    toolBarAppearace.tintColor = .tintColor
    toolBarAppearace.barTintColor = .barTintColor
    
    let buttonAppearance = UIButton.appearance()
    buttonAppearance.tintColor = .tintColor
  }
}

extension UIColor {
  class var tintColor: UIColor {
    if UIScreen.isDarkMode {
      return .white
    } else {
      return UIColor(named: "AccentColor")!
    }
  }
  
  class var barTintColor: UIColor {
    if UIScreen.isDarkMode {
      return .darkText
    } else {
      return .white
    }
  }
}

extension UIScreen {
  static var isDarkMode: Bool {
    return main.traitCollection.userInterfaceStyle == .dark
  }
}

extension UIDevice {
  static var isSimulator: Bool {
    #if targetEnvironment(simulator)
    return true
    #else
    return false
    #endif
  }
}
