//
//  SearchFilesView.swift
//  MiniScanner
//
//  Created by George Makhoul on 08/06/2024.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import UIKit
protocol SearchFilesViewDelegate {
    func searchfor(text: String)
}

final class SearchFilesView: UIView {
    // MARK: - Outlets
    @IBOutlet private weak var view: UIView!
    @IBOutlet private weak var titleLabel: UILabel!
    @IBOutlet private weak var searchButton: UIButton!
    @IBOutlet weak var searchTextField: UITextField!
    @IBOutlet weak var exitButton: UIButton!
    @IBOutlet weak var boxView: UIView!
    
    // MARK: - Properties
    var delegate: SearchFilesViewDelegate?
    
    // MARK: - LifeCycle
    override init(frame: CGRect) {
        super.init(frame: frame)
        setupNib()
    }
    
    required init?(coder aDecoder: NSCoder) {
        super.init(coder: aDecoder)
        
        setupNib()
    }
    
    private func setupNib() {
        Bundle.main.loadNibNamed("SearchFilesView", owner: self, options: nil)
        view.frame = bounds
        view.autoresizingMask = [.flexibleHeight, .flexibleWidth]
        addSubview(view)
        setupUI()
    }
    
    @IBAction func searchTapped(_ sender: UIButton) {
        searchTextField.isHidden = !searchTextField.isHidden
        titleLabel.isHidden = !searchTextField.isHidden
        searchButton.isHidden = !searchTextField.isHidden
        exitButton.isHidden = searchTextField.isHidden
        if !searchTextField.isHidden {
            searchTextField.clearButtonMode = .always
            searchTextField.becomeFirstResponder()
        }
    }
    
    @IBAction func exitButtonTapped(_ sender: UIButton) {
        searchTextField.isHidden = true
        exitButton.isHidden = true
        searchButton.isHidden = false
        titleLabel.isHidden = false
        searchTextField.text = ""
        searchTextField.resignFirstResponder()
        delegate?.searchfor(text: "")
    }
    
    private func setupUI() {
        boxView.layer.cornerRadius = 30
        titleLabel.set(text: "Folder files", color: .titlesText, font: .bold(20))
        searchTextField.isHidden = true
        searchTextField.addTarget(self, action: #selector(textFieldDidChange), for: .editingChanged)
        searchTextField.delegate = self
        titleLabel.isHidden = !searchTextField.isHidden
        searchButton.isHidden = !searchTextField.isHidden
    }
}

// MARK: - TextFieldDelegate
extension SearchFilesView: UITextFieldDelegate {
    @objc func textFieldDidChange() {
        
        if let text = searchTextField.text {
            if text.count >= 1 || text.count == 0 {
                delegate?.searchfor(text: text)
            }
        }
    }
    func textFieldShouldReturn(_ textField: UITextField) -> Bool {
        textField.resignFirstResponder()
        return true
    }
}
