//
//  ShareSheetViewController.swift
//  MiniScanner
//
//  Created by George Makhoul on 10/06/2024.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import UIKit
protocol ShareSheetViewControllerDelegate {
    func whatsappTapped(name: String)
    func telegramTapped(name: String)
    func airdropTapped(name: String)
    func printTapped()
    func moreTapped(name: String)
    func saveTapped(name: String)
}

class ShareSheetViewController: UIViewController {
    // MARK: - Outlets
    @IBOutlet weak var pdfImage: UIImageView!
    @IBOutlet weak var fileNameTextField: UITextField!
    @IBOutlet weak var pagesCountLabel: UILabel!
    @IBOutlet weak var whatsappLabel: UILabel!
    @IBOutlet weak var telegramLabel: UILabel!
    @IBOutlet weak var airdropLabel: UILabel!
    @IBOutlet weak var printLabel: UILabel!
    @IBOutlet weak var moreLabel: UILabel!
    @IBOutlet weak var backgroundView: UIView!
    
    // MARK: - Properties
    var session: MultiPageScanSession?
    var delegate: ShareSheetViewControllerDelegate?
    var selectedFolder: AppConfigurator.Folder?
    
    // MARK: - LifeCycle
    override func viewDidLoad() {
        super.viewDidLoad()
        setupUI()
        setup()
    }
    
    private func setupUI() {
        pagesCountLabel.set(text: "", color: .mainText, font: .regular(16))
        whatsappLabel.set(localized: "Whatsapp", color: .mainText, font: .regular(12))
        telegramLabel.set(localized: "Telegram", color: .mainText, font: .regular(12))
        airdropLabel.set(localized: "Gmail", color: .mainText, font: .regular(12))
        printLabel.set(localized: "Print", color: .mainText, font: .regular(12))
        moreLabel.set(localized: "More", color: .mainText, font: .regular(12))
        whatsappLabel.textAlignment = .center
        telegramLabel.textAlignment = .center
        airdropLabel.textAlignment = .center
        printLabel.textAlignment = .center
        moreLabel.textAlignment = .center
        
        fileNameTextField.placeholder = "File name"
        backgroundView.layer.cornerRadius = 30
        backgroundView.layer.maskedCorners = [.layerMinXMinYCorner, .layerMaxXMinYCorner]
        pdfImage.layer.cornerRadius = 10
        pdfImage.clipsToBounds = true
        pdfImage.contentMode = .scaleAspectFill
    }
    
    private func setup() {
        let _ = self.session?.scannedItems[0].render(completion: { image in
            self.pdfImage.image = image?.retrieveImage()
        })
        pagesCountLabel.set(text: "\(self.session?.scannedItems.count ?? 0) pages")
        
    }
    
    @IBAction func saveTapped(_ sender: UIButton) {
        self.dismiss(animated: true) {
            self.delegate?.saveTapped(name: self.fileNameTextField.text ?? "")
        }
    }
    
    @IBAction func whatsappTapped(_ sender: UIButton) {
        self.dismiss(animated: true) {
            self.delegate?.whatsappTapped(name: self.fileNameTextField.text ?? "")
        }
    }
    
    @IBAction func telegramTapped(_ sender: UIButton) {
        self.dismiss(animated: true) {
            self.delegate?.telegramTapped(name: self.fileNameTextField.text ?? "")
        }

    }
    
    @IBAction func airdropTapped(_ sender: UIButton) {
        self.dismiss(animated: true) {
            self.delegate?.airdropTapped(name: self.fileNameTextField.text ?? "")
        }

    }
    
    @IBAction func printTapped(_ sender: UIButton) {
        delegate?.printTapped()

    }
    
    @IBAction func moreTapped(_ sender: UIButton) {
        self.dismiss(animated: true) {
            self.delegate?.moreTapped(name: self.fileNameTextField.text ?? "")
        }

    }
}
