import UIKit

enum SettingsType: String {
  case url, switcher, segment, none
}

struct SettingsViewModel {
  let imageName: String
  let title: String
  
  var isSwitchOn = false
  var isSwitcherOn: ((Bool) -> Void)? = nil
  
  var urlString: String? = nil
  var type = SettingsType.none
}

final class SettingsTableViewCell: UITableViewCell {
  
  static let ReuseIdentifier = String(describing: SettingsTableViewCell.self)

  @IBOutlet private weak var imgView: UIImageView!
  @IBOutlet private weak var nameLabel: UILabel!
  @IBOutlet private weak var settingsSwitch: UISwitch!
  
  private var isSwitcherOn: ((Bool) -> Void)?

  func configure(with viewModel: SettingsViewModel) {
    imgView.image = UIImage(systemName: viewModel.imageName)
    nameLabel.text = viewModel.title
    isSwitcherOn = viewModel.isSwitcherOn
    settingsSwitch.isOn = viewModel.isSwitchOn
    
    switch viewModel.type {
    case .segment:
      settingsSwitch.isHidden = false
    case .switcher:
      settingsSwitch.isHidden = true
    case .url, .none:
      settingsSwitch.isHidden = true
    }
  }
  
  @IBAction private func didTapSwitching(_ sender: UISwitch) {
    isSwitcherOn?(sender.isOn)
  }
}
