//
//  CustomTabBarView.swift
//  MiniScanner
//
//  Created by George Makhoul on 10/06/2024.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import UIKit
protocol CustomTabBarViewDelegate {
    func scanTapped()
    func fileManagerTapped()
    func editButtonTapped()
    func shareTapped()
}
class CustomTabBarView: UIView {
    // MARK: - Outlet
    @IBOutlet var view: UIView!
    @IBOutlet weak var editImageView: UIView!
    @IBOutlet weak var editImageLabel: UILabel!
    @IBOutlet weak var editImageIcon: UIImageView!
    @IBOutlet weak var scannedImage: UIImageView!
    @IBOutlet weak var badgeView: UIView!
    @IBOutlet weak var badgeLabel: UILabel!
    @IBOutlet weak var scannedImageView: UIView!
    @IBOutlet weak var tabbarImage: UIImageView!
    
    // MARK: - Properties
    var delegate: CustomTabBarViewDelegate?
    
    // MARK: - LifeCycle
    override init(frame: CGRect) {
        super.init(frame: frame)
        setupNib()
    }
    
    required init?(coder aDecoder: NSCoder) {
        super.init(coder: aDecoder)
        
        setupNib()
    }
    
    private func setupNib() {
        Bundle.main.loadNibNamed("CustomTabBarView", owner: self, options: nil)
        view.frame = bounds
        view.autoresizingMask = [.flexibleHeight, .flexibleWidth]
        addSubview(view)
        setupUI()
    }
    
    private func setupUI() {
        editImageIcon.image = UIImage(named: "preview")
        editImageLabel.set(text: "Preview", color: .white, font: .medium(18))
        editImageView.layer.cornerRadius = 10
        editImageView.backgroundColor = .buttonsBlue
        badgeView.layer.cornerRadius = 10
        badgeView.backgroundColor = .red
        
        tabbarImage.image = UIDevice.current.userInterfaceIdiom == .pad ? UIImage(named: "tabbarIpad") : UIImage(named: "tabBar")
    }
    
    func updateScannedView(session: MultiPageScanSession!) {
        if !session.scannedItems.isEmpty {
            editImageView.isHidden = false
            scannedImageView.isHidden = false
            badgeView.isHidden = false
            let items = session.scannedItems
            let _ = items.last?.render {(image) in
                self.scannedImage.image = image?.retrieveImage()
            }
            badgeLabel.set(text: "\(items.count)", color: .white, font: .medium(14))
            badgeLabel.textAlignment = .center
        } else {
            editImageView.isHidden = true
            scannedImageView.isHidden = true
            badgeView.isHidden = true
        }
    }
    
    @IBAction func scanButtonTapped(_ sender: UIButton) {
        delegate?.scanTapped()
    }
    
    @IBAction func filesManagerButtonTapped(_ sender: UIButton) {
        delegate?.fileManagerTapped()
    }
    
    @IBAction func editImageTapped(_ sender: UIButton) {
        delegate?.editButtonTapped()
    }
    
    @IBAction func shareButtonTapped(_ sender: UIButton) {
        delegate?.shareTapped()
    }
}
